
#		Pymol Script for a Pvu II - DNA complex
#		Eric Anderson, Graduate Student
#		Loren Williams, Georgia Tech

reinitialize
bg_color white

load 1EYU.pdb, Complex

# -------- OBJECT: DNA
create DNA, Complex and chain C+D
color wheat, (DNA and name C*)
color red, (DNA and name O*)
color blue, (DNA and name N*)
color yelloworange, (DNA and name P)

# -------- OBJECT: Cartoon DNA
create Cartoon_DNA, DNA
set cartoon_ring_mode=3, Cartoon_DNA
set cartoon_tube_radius=0.3, Cartoon_DNA
hide everything, Cartoon_DNA
show cartoon, Cartoon_DNA

# -------- OBJECT: Stick DNA
create Stick_DNA, DNA
hide everything, Stick_DNA
show stick, Stick_DNA
color green, (Stick_DNA and name C*)
remove resn hoh and Stick_DNA


# -------- OBJECT: WC Bonds
distance WC_Hbond, (name O2,N3,N4 and resn DC and Stick_DNA ), (name N2,N1,O6 and resn DG and Stick_DNA ), 3.27
distance WC_Hbond, (name N3,O4 and resn DT and Stick_DNA ), (name N1,N6 and resn DA and Stick_DNA ), 3.27
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3, WC_Hbond
set dash_gap, 0.4, WC_Hbond


# -------- OBJECT: Protein
create protein, chain A+B
set cartoon_fancy_helices=1, protein
set cartoon_cylindrical_helices,2, protein
set cartoon_loop_radius=0.1, protein
#Yellow: Dimerization interface
#Red: catalytic region
#Green: DNA Recognition Region
color yellow, resi 1-47 and protein
color red, resi 48-80 and protein
color red, resi 98-115 and protein
hide everything, protein
show cartoon, protein

# -------- OBJECT: Catalytic Residues Asp-58, Glu-68, Lys-70

create Asp_58, resi 58 and protein
show stick, Asp_58

create Glu_68, resi 68 and protein
show stick, Glu_68

create Lys_70, resi 70 and protein
show stick, Lys_70

create cat_site, Asp_58 or Glu_68 or Lys_70
delete Asp_58
delete Glu_68
delete Lys_70

label cat_site and /cat_site//B/ASP`58/CB, "Asp58"
label cat_site and /cat_site//A/ASP`58/CB, "Asp58"

label cat_site and /cat_site//B/GLU`68/CA, "Glu68"
label cat_site and /cat_site//A/GLU`68/CA, "Glu68"

label cat_site and /cat_site//B/LYS`70/CB, "Lys70"
label cat_site and /cat_site//A/LYS`70/CB, "Lys70"

# -------- Object: Protein Interface

create protein_interface, (protein) within 6 of (Cartoon_DNA)
hide everything, protein_interface
show stick, protein_interface
remove resn hoh and protein_interface
color gray80, (protein_interface and name C*)
color red, (protein_interface and name O*)
color blue, (protein_interface and name N*)

# -------- Object: DNA_protein_HB
distance DNA_protein_HB, (protein_interface and (name N* or name O*)), (Stick_DNA and (name N* or name O*)), 3.4
color black, DNA_protein_HB
hide labels, DNA_protein_HB
set dash_width, 3, DNA_protein_HB
set dash_gap, 0.4, DNA_protein_HB

# -------- Object: DNA Recognition Region Contacts
create DNA_recog_contacts, /protein_interface//A/LYS`130/* + /protein_interface//A/LYS`126/* + /protein_interface//A/LYS`143/* + /protein_interface//A/ASN`140/* + /protein_interface//A/ASN`141/* + /protein_interface//A/HIS`84/* + /protein_interface//A/HIS`83/* + /protein_interface//B/LYS`93/* + /protein_interface//B/HIS`83/* + /protein_interface//B/HIS`85/* + /protein_interface//B/HIS`84/* + /protein_interface//B/SER`81/* + /protein_interface//B/LYS`143/* + /protein_interface//B/ASN`141/* + /protein_interface//B/ASN`140/* + /protein_interface//B/LYS`130/* + /Stick_DNA//C/DG`3/* + /Stick_DNA//C/DA`4/* + /Stick_DNA//D/DG`12/* + /Stick_DNA//C/DC`5/* + /Stick_DNA//D/DG`11/* + /Stick_DNA//C/DC`6/* + /Stick_DNA//C/DA`7/* + /Stick_DNA//C/DG`8/* + /Stick_DNA//D/DG`8/* + /Stick_DNA//D/DA`7/* + /Stick_DNA//D/DC`5/* + /Stick_DNA//C/DG`12/* + /Stick_DNA//C/DG`11/* + /Stick_DNA//D/DC`6/*

distance DNA_recog_hb, DNA_recog_contacts and chain A+B and (name N* or name O*), DNA_recog_contacts and chain C+D and (name N* or name O*), 3.4


color black, DNA_recog_hb
#hide labels, DNA_recog_hb
set dash_width, 3, DNA_recog_hb
set dash_gap, 0.4, DNA_recog_hb





# -------- Object: Restriction Site C(+3) and G(-3) Contacts

create C+3__G-3_contacts, /Stick_DNA//C/DC`6/* + /protein_interface//A/ASN`141/* +/Stick_DNA//D/DG`11/* + /protein_interface//A/LYS`143/* + /protein_interface//A/SER`81/* + /protein_interface//A/ASN`140/* + /protein_interface//A/ASN`73/*

distance C+3__G-3_hb, C+3__G-3_contacts and chain A+B and (name N* or name O*), C+3__G-3_contacts and chain C+D and (name N* or name O*), 3.4

color black, C+3__G-3_hb
hide labels, C+3__G-3_hb
set dash_width, 3, C+3__G-3_hb
set dash_gap, 0.4, C+3__G-3_hb



# -------- Object: Restriction Site A(+2) and T(-2) Contacts

create A+2__T-2_contacts, /Stick_DNA//C/DA`7/* + /Stick_DNA//D/DT`10/* + /protein_interface//A/SER`71/* + /protein_interface//A/ASN`35/ + /protein_interface//B/GLN`33/* + /protein_interface//A/ASN`140/* + /protein_interface//A/HIS`84/*

distance A+2__T-2_hb, A+2__T-2_contacts and chain A+B and (name N* or name O*), A+2__T-2_contacts and chain C+D and (name N* or name O*), 3.4

color black, A+2__T-2_hb
hide labels, A+2__T-2_hb
set dash_width, 3, A+2__T-2_hb
set dash_gap, 0.4, A+2__T-2_hb


# -------- Object: Restriction Site G(+1) and C(-1) Contacts ------------ ###########LEAVE COMMENT BETWEEN CREATE AND DISTANCE COMMANDS############

create G+1__C-1_contacts, /Stick_DNA//C/DG`8/* + /Stick_DNA//D/DC`9/* + /protein_interface//A/ASN`57/* + /protein_interface//A/ASP`34/* + /protein_interface//B/ASP`34/* + /protein_interface//B/LYS`93/* + /protein_interface//B/HIS`83/* + /protein_interface//A/HIS`84/* + /protein_interface//A/ASN`35/*

#


distance G+1__C-1_hb, G+1__C-1_contacts and chain A+B and (name N* or name O*), G+1__C-1_contacts and chain C+D and (name N* or name O*), 3.4

color black, G+1__C-1_hb
hide labels, G+1__C-1_hb
set dash_width, 3, G+1__C-1_hb
set dash_gap, 0.4, G+1__C-1_hb


# -------- Object: Restriction Site C(-1) and G(+1) Contacts ------------ ###########LEAVE COMMENT BETWEEN CREATE AND DISTANCE COMMANDS############

create C-1__G+1_contacts, /Stick_DNA//C/DC`9/* + /Stick_DNA//D/DG`8/* + /protein_interface//B/ASN`57/* + /protein_interface//B/GLU`68/* + /protein_interface//B/ASP`34/* + /protein_interface//A/ASP`34/* + /protein_interface//B/HIS`84/* + /protein_interface//A/HIS`83/*

#

distance C-1__G+1_hb, C-1__G+1_contacts and chain A+B and (name N* or name O*), C-1__G+1_contacts and chain C+D and (name N* or name O*), 3.4

color black, C-1__G+1_hb
hide labels, C-1__G+1_hb
set dash_width, 3, C-1__G+1_hb
set dash_gap, 0.4, C-1__G+1_hb




# -------- Object: Restriction Site T(-2) and A(+2) Contacts

create T-2__A+2_contacts, /Stick_DNA//C/DT`10/* + /Stick_DNA//D/DA`7/* + /protein_interface//B/ASN`140/* + /protein_interface//B/HIS`84/* + /protein_interface//A/GLN`33/* + /protein_interface//B/SER`71/* + /protein_interface//B/ASN`35/*

distance T-2__A+2_hb, T-2__A+2_contacts and chain A+B and (name N* or name O*), T-2__A+2_contacts and chain C+D and (name N* or name O*), 3.4

color black, T-2__A+2_hb
hide labels, T-2__A+2_hb
set dash_width, 3, T-2__A+2_hb
set dash_gap, 0.4, T-2__A+2_hb


# -------- Object: Restriction Site G(-3) and C(+3) Contacts

create G-3__C+3_contacts, /Stick_DNA//C/DG`11/* + /Stick_DNA//D/DC`6/* + /protein_interface//B/LYS`143/* + /protein_interface//B/SER`81/* + /protein_interface//B/ASN`141/* + /protein_interface//B/ASN`140/*

distance G-3__C+3_hb, G-3__C+3_contacts and chain A+B and (name N* or name O*), G-3__C+3_contacts and chain C+D and (name N* or name O*), 3.4

color black, G-3__C+3_hb
hide labels, G-3__C+3_hb
set dash_width, 3, G-3__C+3_hb
set dash_gap, 0.4, G-3__C+3_hb

# -------- Display

disable all
enable Cartoon_DNA
enable protein


set_view (\
    -0.489145577,   -0.162717938,    0.856892109,\
    -0.870907903,    0.037574835,   -0.490011603,\
     0.047535844,   -0.985959589,   -0.160091370,\
    -0.000000613,   -0.000000864, -116.667800903,\
    20.821352005,   16.543317795,    4.799662590,\
    26.899627686,  206.436004639,  -20.000000000 )

